@@ -53,8 +53,9 @@ class MetaSearchResult(BaseModel):
     media_type: MediaType = None
     season_number: int = None
 
-    def __init__(self, data: Dict):
-        utils.copy_value(data, self)
+    def __init__(self, data: Optional[Dict] = None):
+        if data:
+            utils.copy_value(data, self)
 
 
 class AmrApi:
