@@ -11,13 +11,86 @@ import cn2an
 from moviebotapi.core.models import MediaType
 
 
-def _parse_field_value(field_value):
+def trans_unit_to_mb(size: float, unit: str) -> float:
+    """
+    按文件大小尺寸规格，转换成MB单位的数字
+    :param size:
+    :param unit:
+    :return:
+    """
+    if unit == 'GB' or unit == 'GiB':
+        return round(size * 1024, 2)
+    elif unit == 'MB' or unit == 'MiB':
+        return round(size, 2)
+    elif unit == 'KB' or unit == 'KiB':
+        return round(size / 1024, 2)
+    elif unit == 'TB' or unit == 'TiB':
+        return round(size * 1024 * 1024, 2)
+    elif unit == 'PB' or unit == 'PiB':
+        return round(size * 1024 * 1024 * 1024, 2)
+    else:
+        return size
+
+
+def trans_size_str_to_mb(size: str):
+    """
+    把一个字符串格式的文件尺寸单位，转换成MB单位的标准数字
+    :param size:
+    :return:
+    """
+    if not size:
+        return 0.0
+    s = None
+    u = None
+    if size.find(' ') != -1:
+        arr = size.split(' ')
+        s = arr[0]
+        u = arr[1]
+    else:
+        if size.endswith('GB'):
+            s = size[0:-2]
+            u = 'GB'
+        elif size.endswith('GiB'):
+            s = size[0:-3]
+            u = 'GB'
+        elif size.endswith('MB'):
+            s = size[0:-2]
+            u = 'MB'
+        elif size.endswith('MiB'):
+            s = size[0:-3]
+            u = 'MB'
+        elif size.endswith('KB'):
+            s = size[0:-2]
+            u = 'KB'
+        elif size.endswith('KiB'):
+            s = size[0:-3]
+            u = 'KB'
+        elif size.endswith('TB'):
+            s = size[0:-2]
+            u = 'TB'
+        elif size.endswith('TiB'):
+            s = size[0:-3]
+            u = 'TB'
+        elif size.endswith('PB'):
+            s = size[0:-2]
+            u = 'PB'
+        elif size.endswith('PiB'):
+            s = size[0:-3]
+            u = 'PB'
+    if not s:
+        return 0.0
+    if s.find(',') != -1:
+        s = s.replace(',', '')
+    return trans_unit_to_mb(float(s), u)
+
+
+def parse_field_value(field_value):
     if isinstance(field_value, decimal.Decimal):  # Decimal -> float
         field_value = round(float(field_value), 2)
     elif isinstance(field_value, datetime.datetime):  # datetime -> str
         field_value = str(field_value)
     elif isinstance(field_value, list):
-        field_value = [_parse_field_value(i) for i in field_value]
+        field_value = [parse_field_value(i) for i in field_value]
     if hasattr(field_value, 'to_json'):
         field_value = field_value.to_json()
     elif isinstance(field_value, Enum):
@@ -25,7 +98,7 @@ def _parse_field_value(field_value):
     elif isinstance(field_value, Dict):
         val = {}
         for key_ in field_value:
-            val[key_] = _parse_field_value(field_value[key_])
+            val[key_] = parse_field_value(field_value[key_])
         field_value = val
     return field_value
 
@@ -42,7 +115,7 @@ def json_object(cls):
 
         for column in self.__dict__:
             if hasattr(self, column):
-                model_json[column] = _parse_field_value(getattr(self, column))
+                model_json[column] = parse_field_value(getattr(self, column))
         if '_sa_instance_state' in model_json:
             del model_json['_sa_instance_state']
         return model_json
@@ -111,7 +184,7 @@ def _dict_value(value):
         return value
 
 
-def parse_value(func, value):
+def parse_value(func, value, default_value=None):
     if value is not None:
         if func == bool:
             if value in (1, True, "1", "true"):
@@ -123,11 +196,21 @@ def parse_value(func, value):
 
         elif func in (int, float):
             try:
+                if isinstance(value, str):
+                    value = value.replace(',', '')
                 return func(value)
             except ValueError:
                 return float('nan')
         elif func == datetime.datetime:
-            return datetime.datetime.strptime(value, '%Y-%m-%d %H:%M:%S')
+            if isinstance(value, datetime.datetime):
+                return value
+            elif isinstance(value, str):
+                if value:
+                    return datetime.datetime.strptime(value, '%Y-%m-%d %H:%M:%S')
+                else:
+                    return None
+            else:
+                return None
         elif func in [Dict, dict]:
             return _dict_value(value)
         elif func in [List, list]:
@@ -142,7 +225,8 @@ def parse_value(func, value):
                     res.append(parse_value(func.__args__[0], x))
                 return res
         return func(value)
-    return value
+    else:
+        return default_value
 
 
 """文件后缀"""
